#delimit;
cd "C:\Users\cemood\Box Sync\redflag";
use "C:\Users\cemood\Box Sync\redflag\US suicide dataset_20181220_updated.dta", clear;
log using redflag.2007.mvps.log, replace;
scalar drop _all;

tsset state year;

/***************************************************/
/* CT implemented red flag law 10/1/1999           */
/* CT increased use of law in 2007                 */
/* IN implemented red flag law 7/1/2005            */
/* CA implemented red flag law 1/1/2016            */
/* OR 1/1/2018  too recent to analyze              */
/* WA 12/8/2016                                    */
/***************************************************/
drop crmurpc lcrmurpc;
gen crmurpc=100000*(crmur/poptot);
gen lcrmurpc=100*log(crmurpc);
label var lcrmurpc "Log murder rate";


/* create dummy and spline */
gen dumCT=(year>2007)*(stnm=="CT");
gen dumIN=(year>2005)*(stnm=="IN");replace dumIN=.25 if year==2005 & stnm=="IN";
gen dumCA=(year>=2016)*(stnm=="CA");
gen dumWA=(year>2016)*(stnm=="WA");replace dumWA=.06 if year==2016 & stnm=="WA";
gen rfdum=0;
replace rfdum=dumCT+dumIN+dumCA+dumWA;
label var rfdum "Red flag dummy variable";

gen sCT=(year-2007)*(stnm=="CT")*(year>2007);
gen sIN=(year-2005)*(stnm=="IN")*(year>2005);
gen sCA=(year-2016)*(stnm=="CA")*(year>=2016);
gen sWA=(year-2016)*(stnm=="WA")*(year>2016);

gen rfspline=sCT+sIN+sCA+sWA;
label var rfspline "Red flag spline variable";

drop pp1534;

/* state and year dummies */
quietly: tab year, gen(yrdum);
quietly: tab state, gen(stdum);


replace employ=employ/poptot;
replace empconpc=100*empcon/poptot;
replace empmilpc=100*empmil/poptot;

/* use updated prison rate, income, density */
replace prisonpc=PrisonRate;
replace incomepc=IncomeperCapita;
replace density=poptot/area;
gen prisonpc_1=L.prisonpc;
gen policepc_1=L.policepc;
gen lcrmurpc_1=L.lcrmurpc;
gen lcrmurpc_2=LL.lcrmurpc;
gen arrestvio=Violentcrimearrestrate;

label var arrestvio "Arrest rate violent crime";
label var prisonpc_1 "Prison per cap, lagged";
label var policepc_1 "Police per cap, lagged";
label var lcrmurpc_1 "Log gun murder rate, lagged";
label var lcrmurpc_2 "Log gun murder rate, lagged twice";
label var rwelfare "Real welfare per capita";
label var pp1519 "Percent Population 15-19";
label var pp2024 "Percent Population 20-24";
label var pp2529 "Percent Population 25-29";
label var pp3034 "Percent Population 30-34";
label var pp3539 "Percent Population 35-39";
label var pp4044 "Percent Population 40-44";
label var pp4549 "Percent Population 45-49";
label var pp5054 "Percent Population 50-54";
label var pp5559 "Percent Population 55-59"; 
label var pp6064 "Percent Population 60-64";
label var pp6500 "Percent Population 65+";

/* dummy regression */

xtnbreg nkilled_mvps
rfdum
trend 
density
crack 
arrestvio
prisonpc_1 
exec
tis strike3
shall castle syg
fse wait bkgp bkghg safe jban 
onegun snsban 
incomepc povrate pctblack
unrate employ empmilpc empconpc
pp* yrdum*
, fe irr;


testparm pp* yrdum* pp*
trend density crack arrestvio prisonpc_1 exec 
tis castle fse wait bk* snsban
incomepc empmil empcon
employ jban shall;

/* dummy and spline */

xtnbreg nkilled_mvps
rfdum rfspline
strike3
syg
safe 
onegun 
povrate pctblack
unrate 
, fe irr;

outreg using table_mvps, nosubstat varlabels   starlevels(5 1) replace ctitles(Variable,Coeff, T-ratio) 
keep(
rfdum rfspline
strike3
syg
safe 
onegun 
povrate pctblack
unrate 
) summstat(N);

/* dummy only */

xtnbreg nkilled_mvps
rfdum
strike3
syg
safe 
onegun 
povrate pctblack
unrate 
, fe irr;

outreg using table_mvps, nosubstat varlabels   starlevels(5 1) replace ctitles(Variable,Coeff, T-ratio) merge
keep(
rfdum
strike3
syg
safe 
onegun 
povrate pctblack
unrate 
) summstat(N);

/* spline only */

xtnbreg nkilled_mvps
rfspline
strike3
syg
safe 
onegun 
povrate pctblack
unrate 
, fe irr;

outreg using table_mvps, nosubstat varlabels   starlevels(5 1) replace ctitles(Variable,Coeff, T-ratio) merge
keep(
rfspline
strike3
syg
safe 
onegun 
povrate pctblack
unrate 
) summstat(N);

/* Do not need placebo law analysis because t-ratios are not significantly different from zero */

log close;
