#delimit;
cd "C:\Users\cemood\Box Sync\redflag";
use "C:\Users\cemood\Box Sync\redflag\US suicide dataset_20181220_updated.dta", clear;
log using redflag.robust.murder.pre.post.dummies.log, replace;
scalar drop _all;

tsset state year;

/***************************************************/
/* CT implemented red flag law 10/1/1999           */
/* IN implemented red flag law 7/1/2005            */
/* CA implemented red flag law 1/1/2016            */
/* OR 1/1/2018  too recent to analyze              */
/* WA 12/8/2016                                    */
/***************************************************/
drop crmurpc lcrmurpc;
gen crmurpc=100000*(crmur/poptot);
gen lcrmurpc=100*log(crmurpc);
label var lcrmurpc "Log murder rate";


drop pp1534;

/* CT  */
gen rfCT_12=0;gen rfCT_34=0;gen rfCT_56=0;gen rfCT_7up=0;
gen rfCT_0=(year==1999)*(stnm=="CT");
replace rfCT_12=1   if stnm=="CT" & (year ==1999+1  | year==1999+2);
replace rfCT_34=1   if stnm=="CT" & (year ==1999+3  | year==1999+4);
replace rfCT_56=1   if stnm=="CT" & (year ==1999+5  | year==1999+6);
replace rfCT_7up=1   if stnm=="CT" & (year>=1999+7);

gen preCT_12=0;gen preCT_34=0;
replace preCT_12=1 if stnm=="CT" & (year ==1999-1  | year==1999-2);
replace preCT_34=1 if stnm=="CT" & (year ==1999-3  | year==1999-4);


/* IN */

gen rfIN_12=0;gen rfIN_34=0;gen rfIN_56=0;gen rfIN_7up=0;
gen rfIN_0=(year==2005)*(stnm=="IN");
replace rfIN_12=1   if stnm=="IN" & (year ==2005+1  | year==2005+2);
replace rfIN_34=1   if stnm=="IN" & (year ==2005+3  | year==2005+4);
replace rfIN_56=1   if stnm=="IN" & (year ==2005+5  | year==2005+6);
replace rfIN_7up=1  if stnm=="IN" & (year>=2005+7);

gen preIN_12=0;gen preIN_34=0;
replace preIN_12=1 if stnm=="IN" & (year ==2005-1  | year==2005-2);
replace preIN_34=1 if stnm=="IN" & (year ==2005-3  | year==2005-4);

/* CA */
gen rfCA_0=0;gen rfCA_12=0;
replace rfCA_0=1 if stnm=="CA" & (year==2016);
replace rfCA_12=1   if stnm=="CA" & (year ==2016+1  | year==2016+2);

gen preCA_12=0;gen preCA_34=0;
replace preCA_12=1 if stnm=="CA" & (year ==2016-1  | year==2016-2);
replace preCA_34=1 if stnm=="CA" & (year ==2016-3  | year==2016-4);

/* WA */
gen rfWA_0=0;
replace rfWA_0=1 if stnm=="WA" & (year==2017);

gen preWA_12=0;gen preWA_34=0;
replace preWA_12=1 if stnm=="WA" & (year ==2017-1  | year==2017-2);
replace preWA_34=1 if stnm=="WA" & (year ==2017-3  | year==2017-4);


/* state and year dummies */
quietly: tab year, gen(yrdum);
quietly: tab state, gen(stdum);


replace employ=employ/poptot;
replace empconpc=100*empcon/poptot;
replace empmilpc=100*empmil/poptot;

/* use updated prison rate, income, density */
replace prisonpc=PrisonRate;
replace incomepc=IncomeperCapita;
replace density=poptot/area;
gen prisonpc_1=L.prisonpc;
gen policepc_1=L.policepc;
gen lcrmurpc_1=L.lcrmurpc;
gen lcrmurpc_2=LL.lcrmurpc;
gen arrestvio=Violentcrimearrestrate;

label var arrestvio "Arrest rate violent crime";
label var prisonpc_1 "Prison per cap, lagged";
label var policepc_1 "Police per cap, lagged";
label var lcrmurpc_1 "Log gun murder rate, lagged";
label var lcrmurpc_2 "Log gun murder rate, lagged twice";
label var rwelfare "Real welfare per capita";
label var pp1519 "Percent Population 15-19";
label var pp2024 "Percent Population 20-24";
label var pp2529 "Percent Population 25-29";
label var pp3034 "Percent Population 30-34";
label var pp3539 "Percent Population 35-39";
label var pp4044 "Percent Population 40-44";
label var pp4549 "Percent Population 45-49";
label var pp5054 "Percent Population 50-54";
label var pp5559 "Percent Population 55-59"; 
label var pp6064 "Percent Population 60-64";
label var pp6500 "Percent Population 65+";

regress lcrmurpc 
rfCT_0 rfCT_12 rfCT_34 rfCT_56 rfCT_7up
rfIN_0 rfIN_12 rfIN_34 rfIN_56 rfIN_7up
rfCA* rfWA*
pre*
trend 
density
crack arrestvio 
prisonpc_1 
exec
tis strike3
shall castle syg
fse wait bkgp bkghg safe jban 
onegun snsban 
incomepc povrate pctblack
unrate employ empmilpc empconpc
pp*
lcrmurpc_1 lcrmurpc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);



/* test mean of pre-law to mean of post-law dummies */
scalar diffCT= (.25*_b[rfCT_12]+.25*_b[rfCT_34]+.25*_b[rfCT_56]+.25*_b[rfCT_7up])-(.5*_b[preCT_12]+.5*_b[preCT_34]);
scalar diffIN= (.25*_b[rfIN_12]+.25*_b[rfIN_34]+.25*_b[rfIN_56]+.25*_b[rfIN_7up])-(.5*_b[preIN_12]+.5*_b[preIN_34]);
test (.25*_b[rfCT_12]+.25*_b[rfCT_34]+.25*_b[rfCT_56]+.25*_b[rfCT_7up])=(.5*_b[preCT_12]+.5*_b[preCT_34]);scalar xF_diffCT=r(F);
test (.25*_b[rfIN_12]+.25*_b[rfIN_34]+.25*_b[rfIN_56]+.25*_b[rfIN_7up])=(.5*_b[preIN_12]+.5*_b[preIN_34]);scalar xF_diffIN=r(F);
scalar list diffCT diffIN;


/* keep t-ratios for placebo law program */
scalar xrfCT_0=_b[rfCT_0]/_se[rfCT_0];
scalar xrfCT_12=_b[rfCT_12]/_se[rfCT_12];
scalar xrfCT_34=_b[rfCT_34]/_se[rfCT_34];
scalar xrfCT_56=_b[rfCT_56]/_se[rfCT_56];
scalar xrfCT_7up=_b[rfCT_7up]/_se[rfCT_7up];
scalar xpreCT_12=_b[preCT_12]/_se[preCT_12];
scalar xpreCT_34=_b[preCT_34]/_se[preCT_34];


scalar xrfIN_0=_b[rfIN_0]/_se[rfIN_0];
scalar xrfIN_12=_b[rfIN_12]/_se[rfIN_12];
scalar xrfIN_34=_b[rfIN_34]/_se[rfIN_34];
scalar xrfIN_56=_b[rfIN_56]/_se[rfIN_56];
scalar xrfIN_7up=_b[rfIN_7up]/_se[rfIN_7up]; 
scalar xpreIN_12=_b[preIN_12]/_se[preIN_12];
scalar xpreIN_34=_b[preIN_34]/_se[preIN_34];

scalar xrfCA_0=_b[rfCA_0]/_se[rfCA_0];
scalar xrfCA_12=_b[rfCA_12]/_se[rfCA_12];
scalar xpreCA_12=_b[preCA_12]/_se[preCA_12];
scalar xpreCA_34=_b[preCA_34]/_se[preCA_34];

scalar xrfWA_0=_b[rfWA_0]/_se[rfWA_0];
scalar xpreWA_12=_b[preWA_12]/_se[preWA_12];
scalar xpreWA_34=_b[preWA_34]/_se[preWA_34];

* test demographic variables as a group */
testparm pp*;

/* test year dummies as a group */
testparm yrdum*;

/* test state trends as a group */
testparm tr2-tr51;


/* save coeffs and sterrs  */
mata: b=st_matrix("e(b)");
mata: se=sqrt(diagonal(st_matrix("e(V)")));
mata: st_matrix("coeff",b);
mata: st_matrix("se",se);
mata: st_matrix_list("coeff");
mata: st_matrix_list("se");

/* coeffs and standard errors */
putexcel set ghr, replace;
putexcel A1=matrix(coeff);
putexcel A2=matrix(se);



/* aggregation tests */


/* test for equality across time, within states */

test rfCT_0=rfCT_12=rfCT_34=rfCT_56=rfCT_7up;
test rfIN_0=rfIN_12=rfIN_34=rfIN_56=rfIN_7up;


/* test for equality across states, within years */

test rfCT_0=rfIN_0=rfCA_0;
test rfCT_12=rfIN_12;
test rfCT_34=rfIN_34;
test rfCT_56=rfIN_56;
test rfCT_7up=rfIN_7up;


/* overall aggregation test */
test rfCT_0=rfIN_0=rfCA_0, accumulate;
test rfCT_12=rfIN_12, accumulate;
test rfCT_34=rfIN_34, accumulate;
test rfCT_56=rfIN_56, accumulate;
test rfCT_7up=rfIN_7up, accumulate;



/* test dummies as a group for significance */
testparm rf*_*;
/* test pre-law dummies for significance */
testparm pre*_*;


/* test dummy long run sum  across all states */

scalar lrsum=_b[rfIN_7up]+_b[rfCT_7up];

test
_b[rfIN_7up]+_b[rfCT_7up]=0; scalar xF_lrsum=r(F);


/* compute weighted sum of long run post-law dummies */

scalar popCT=3577000;
scalar popIN=6491000;
scalar popsum=popCT+popIN;
scalar wtCT=popCT/popsum;
scalar wtIN=popIN/popsum;

scalar wtlrsum=_b[rfIN_7up]*wtIN+_b[rfCT_7up]*wtCT;

scalar list;

/* test dummy post-law weighted sum */

test _b[rfIN_7up]*wtIN+_b[rfCT_7up]*wtCT=0;scalar xF_wtlrsum=r(F);

/* test pre-law dummies for zero sum */
test preCT_12+preCT_34=0;
test preIN_12+preIN_34=0;

/* test for serial correlation  */
/* for information only, clustering cures autocorr */

predict e, resid;

regress e L.e
rfCT_0 rfCT_12 rfCT_34 rfCT_56 rfCT_7up
rfIN_0 rfIN_12 rfIN_34 rfIN_56 rfIN_7up
rfCA* rfWA*
pre*
trend 
density
crack arrestvio 
prisonpc_1 
exec
tis strike3
shall castle syg
fse wait bkgp bkghg safe jban 
onegun snsban 
incomepc povrate pctblack
unrate employ empmilpc empconpc
pp*
lcrmurpc_1 lcrmurpc_2
yrdum* tr2-tr51 stdum*, vce(cluster state);

/* save for placebo law program */
tempfile temp1;
save "`temp1'";

*****************************************/
/***** placebo law program          *****/
/* generate critical values for t-test  */
/****************************************/

drop rf*;

program drop _all;
set seed 135797531;

program placebo, rclass;

keep state year stnm poptot 
lcrmurpc 
trend 
 bkgp
density
crack arrestvio beerpc
prisonpc policepc
exec
tis strike3
shall castle syg
fse wait bkghg safe jban 
onegun snsban 
incomepc rwelfarepc povrate pctblack
unrate employ empmilpc empconpc
pp* tr*
yrdum*  stdum*;

* randomly choose without replacement 6 of 51 states, but skip DC=9 (not in sample) ;

mata: x=jumble(range(1,51,1));
mata: st_matrix("x",x);

/* p1 */
scalar p1=x[1,1];
forvalues i=1(1)51 {;
display p1;
if p1==7 | p1==9 | p1==15 {;
scalar p1=x[1+`i',1];
display as text "new p1=" p1;
continue;
};
else {;
continue,break;
};
};


/* p2 */
scalar p2=x[2,1];
forvalues i=1(1)51 {;
if p2==7 | p2==9 | p2==15 | p2==p1 {;
scalar p2=x[1+`i',1];
display p2;
continue;
};
else {;
continue,break;
};
};


/* p3 */
scalar p3=x[3,1];
forvalues i=1(1)51 {;
if p3==7 | p3==9 | p3==15 | p3==p1 | p3==p2 {;
scalar p3=x[1+`i',1];
display p3;
continue;
};
else {;
continue,break;
};
};


/* p4 */
scalar p4=x[4,1];
forvalues i=1(1)51 {;
if p4==7 | p4==9 | p4==15 | p4==p1 | p4==p2 | p4==p3 {;
scalar p4=x[1+`i',1];
display p4;
continue;
};
else {;
continue,break;
};
};


/* CT  */
gen rfCT_12=0;gen rfCT_34=0;gen rfCT_56=0;gen rfCT_7up=0;
gen rfCT_0=.25*(year==1999)*(state==p1);
replace rfCT_12=1   if state==p1 & (year ==1999+1  | year==1999+2);
replace rfCT_34=1   if state==p1 & (year ==1999+3  | year==1999+4);
replace rfCT_56=1   if state==p1 & (year ==1999+5  | year==1999+6);
replace rfCT_7up=1   if state==p1 & (year>=1999+7);

gen preCT_12=0;gen preCT_34=0;
replace preCT_12=1 if state==p1 & (year ==1999-1  | year==1999-2);
replace preCT_34=1 if state==p1 & (year ==1999-3  | year==1999-4);

/* IN */

gen rfIN_12=0;gen rfIN_34=0;gen rfIN_56=0;gen rfIN_7up=0;
gen rfIN_0=(year==2005)*(state==p2);
replace rfIN_12=1   if state==p2 & (year ==2005+1  | year==2005+2);
replace rfIN_34=1   if state==p2 & (year ==2005+3  | year==2005+4);
replace rfIN_56=1   if state==p2 & (year ==2005+5  | year==2005+6);
replace rfIN_7up=1   if state==p2 & (year>=2005+7 );

gen preIN_12=0;gen preIN_34=0;
replace preIN_12=1 if state==p2 & (year ==2005-1  | year==2005-2);
replace preIN_34=1 if state==p2 & (year ==2005-3  | year==2005-4);

/* CA */
gen rfCA_0=0;gen rfCA_12=0;
replace rfCA_0=1 if state==p3 & (year==2016);
replace rfCA_12=1 if state==p3 & (year ==2016+1  | year==2016+2);

gen preCA_12=0;gen preCA_34=0;
replace preCA_12=1 if state==p3 & (year ==2016-1  | year==2016-2);
replace preCA_34=1 if state==p3 & (year ==2016-3  | year==2016-4);

/* WA */
gen rfWA_0=0;
replace rfWA_0=1 if state==p4 & (year==2017);

gen preWA_12=0;gen preWA_34=0;
replace preWA_12=1 if state==p4 & (year ==2017-1  | year==2017-2);
replace preWA_34=1 if state==p4 & (year ==2017-3  | year==2017-4);

gen lcrmurpc_1=L.lcrmurpc;
gen lcrmurpc_2=L2.lcrmurpc;
gen prisonpc_1=L.prisonpc;
gen policepc_1=L.policepc;

regress lcrmurpc 
rfCT_0 rfCT_12 rfCT_34 rfCT_56 rfCT_7up
rfIN_0 rfIN_12 rfIN_34 rfIN_56 rfIN_7up
rfCA* rfWA*
pre*
trend 
density
crack arrestvio 
prisonpc_1 
exec
tis strike3
shall castle syg
fse wait bkgp bkghg safe jban 
onegun snsban 
incomepc povrate pctblack
unrate employ empmilpc empconpc
pp*
yrdum*  stdum* 
tr2-tr51
/*[weight=poptot]*/
, robust cluster(state);

scalar diffCT= (.25*_b[rfCT_12]+.25*_b[rfCT_34]+.25*_b[rfCT_56]+.25*_b[rfCT_7up])-(.5*_b[preCT_12]+.5*_b[preCT_34]);
scalar diffIN= (.25*_b[rfIN_12]+.25*_b[rfIN_34]+.25*_b[rfIN_56]+.25*_b[rfIN_7up])-(.5*_b[preIN_12]+.5*_b[preIN_34]);
test (.25*_b[rfCT_12]+.25*_b[rfCT_34]+.25*_b[rfCT_56]+.25*_b[rfCT_7up])=(.5*_b[preCT_12]+.5*_b[preCT_34]);return scalar F_diffCT=r(F);
test (.25*_b[rfIN_12]+.25*_b[rfIN_34]+.25*_b[rfIN_56]+.25*_b[rfIN_7up])=(.5*_b[preIN_12]+.5*_b[preIN_34]);return scalar F_diffIN=r(F);


/* test dummy long run sum  across all states */

scalar lrsum=_b[rfIN_7up]+_b[rfCT_7up];

test
_b[rfIN_7up]+_b[rfCT_7up]=0; return scalar F_lrsum=r(F);


/* compute weighted sum of post-law dummies */

scalar popCT=3577000;
scalar popIN=6491000;
scalar popsum=popCT+popIN;
scalar wtCT=popCT/popsum;
scalar wtIN=popIN/popsum;

scalar wtlrsum=_b[rfIN_7up]*wtIN+_b[rfCT_7up]*wtCT;

scalar list;

/* test dummy post-law weighted sum */

test _b[rfIN_7up]*wtIN+_b[rfCT_7up]*wtCT=0;return scalar F_wtlrsum=r(F);

end;


simulate placebo _b _se F_lrsum=r(F_lrsum) F_wtlrsum=r(F_wtlrsum) F_diffCT=r(F_diffCT) F_diffIN=r(F_diffIN) , reps(1000);

/* get scalars from temp1 */
tempfile temp2;
save "`temp2'";

use `temp1';
drop _all;
set obs 1000;
gen index=_n;
sum;
scalar list;
save `temp1', replace;
use `temp2';
gen index=_n;
merge 1:1 index using `temp1';


sum F_wtlrsum,detail;scalar cvwtsum=r(p95);
sum F_lrsum,detail;scalar cvsum=r(p95);

scalar list;

/* standard errors for graph error bands */

sum b_rfCT_0;scalar V=r(Var);scalar sd_rfCT_0=sqrt(V);
sum b_rfCT_12;scalar V=r(Var);scalar sd_rfCT_12=sqrt(V);
sum b_rfCT_34;scalar V=r(Var);scalar sd_rfCT_34=sqrt(V);
sum b_rfCT_56;scalar V=r(Var);scalar sd_rfCT_56=sqrt(V);
sum b_rfCT_7up;scalar V=r(Var);scalar sd_rfCT_7up=sqrt(V);

sum b_preCT_12;scalar V=r(Var);scalar sd_preCT_12=sqrt(V);
sum b_preCT_34;scalar V=r(Var);scalar sd_preCT_34=sqrt(V);


sum b_rfIN_0;scalar V=r(Var);scalar sd_rfIN_0=sqrt(V);
sum b_rfIN_12;scalar V=r(Var);scalar sd_rfIN_12=sqrt(V);
sum b_rfIN_34;scalar V=r(Var);scalar sd_rfIN_34=sqrt(V);
sum b_rfIN_56;scalar V=r(Var);scalar sd_rfIN_56=sqrt(V);
sum b_rfIN_7up;scalar V=r(Var);scalar sd_rfIN_7up=sqrt(V);

sum b_preIN_12;scalar V=r(Var);scalar sd_preIN_12=sqrt(V);
sum b_preIN_34;scalar V=r(Var);scalar sd_preIN_34=sqrt(V);
scalar drop V;

/* placebo t-ratios */

gen t_rfCT_0=b_rfCT_0/se_rfCT_0;gen tt_rfCT_0=abs(t_rfCT_0);
gen t_rfCT_12=b_rfCT_12/se_rfCT_12;gen tt_rfCT_12=abs(t_rfCT_12);
gen t_rfCT_34=b_rfCT_34/se_rfCT_34;gen tt_rfCT_34=abs(t_rfCT_34);
gen t_rfCT_56=b_rfCT_56/se_rfCT_56;gen tt_rfCT_56=abs(t_rfCT_56);
gen t_rfCT_7up=b_rfCT_7up/se_rfCT_7up;gen tt_rfCT_7up=abs(t_rfCT_7up);

gen t_preCT_12=b_preCT_12/se_preCT_12;gen tt_preCT_12=abs(t_preCT_12);
gen t_preCT_34=b_preCT_34/se_preCT_34;gen tt_preCT_34=abs(t_preCT_34);

gen t_rfIN_0=b_rfIN_0/se_rfIN_0;gen tt_rfIN_0=abs(t_rfIN_0);
gen t_rfIN_12=b_rfIN_12/se_rfIN_12;gen tt_rfIN_12=abs(t_rfIN_12);
gen t_rfIN_34=b_rfIN_34/se_rfIN_34;gen tt_rfIN_34=abs(t_rfIN_34);
gen t_rfIN_56=b_rfIN_56/se_rfIN_56;gen tt_rfIN_56=abs(t_rfIN_56);
gen t_rfIN_7up=b_rfIN_7up/se_rfIN_7up;gen tt_rfIN_7up=abs(t_rfIN_7up);

gen t_preIN_12=b_preIN_12/se_preIN_12;gen tt_preIN_12=abs(t_preIN_12);
gen t_preIN_34=b_preIN_34/se_preIN_34;gen tt_preIN_34=abs(t_preIN_34);

gen t_rfCA_0=b_rfCA_0/se_rfCA_0;gen tt_rfCA_0=abs(t_rfCA_0);
gen t_rfCA_12=b_rfCA_12/se_rfCA_12;gen tt_rfCA_12=abs(t_rfCA_12);
gen t_preCA_12=b_preCA_12/se_preCA_12;gen tt_preCA_12=abs(t_preCA_12);
gen t_preCA_34=b_preCA_34/se_preCA_34;gen tt_preCA_34=abs(t_preCA_34);

gen t_rfWA_0=b_rfWA_0/se_rfWA_0;gen tt_rfWA_0=abs(t_rfWA_0);
gen t_preWA_12=b_preWA_12/se_preWA_12;gen tt_preWA_12=abs(t_preWA_12);
gen t_preWA_34=b_preWA_34/se_preWA_34;gen tt_preWA_34=abs(t_preWA_34);


/* p-values for t-statistics */

sum tt_rfCT_0 if tt_rfCT_0>abs(xrfCT_0);scalar nCT0=r(N);
sum tt_rfCT_12 if tt_rfCT_12>abs(xrfCT_12);scalar nCT12=r(N);
sum tt_rfCT_34 if tt_rfCT_34>abs(xrfCT_34);scalar nCT34=r(N);
sum tt_rfCT_56 if tt_rfCT_56>abs(xrfCT_56);scalar nCT56=r(N);
sum tt_rfCT_7up if tt_rfCT_7up>abs(xrfCT_7up);scalar nCT7up=r(N);

sum tt_preCT_12 if tt_preCT_12>abs(xpreCT_12);scalar npreCT12=r(N);
sum tt_preCT_34 if tt_preCT_34>abs(xpreCT_34);scalar npreCT34=r(N);

sum tt_rfIN_0 if tt_rfIN_0>abs(xrfIN_0);scalar nIN0=r(N);
sum tt_rfIN_12 if tt_rfIN_12>abs(xrfIN_12);scalar nIN12=r(N);
sum tt_rfIN_34 if tt_rfIN_34>abs(xrfIN_34);scalar nIN34=r(N);
sum tt_rfIN_56 if tt_rfIN_56>abs(xrfIN_56);scalar nIN56=r(N);
sum tt_rfIN_7up if tt_rfIN_7up>abs(xrfIN_7up);scalar nIN7up=r(N);

sum tt_preIN_12 if tt_preIN_12>abs(xpreIN_12);scalar npreIN12=r(N);
sum tt_preIN_34 if tt_preIN_34>abs(xpreIN_34);scalar npreIN34=r(N);

sum tt_rfCA_0 if tt_rfCA_0>abs(xrfCA_0);scalar nCA0=r(N);
sum tt_rfCA_12 if tt_rfCA_12>abs(xrfCA_12);scalar nCA12=r(N);
sum tt_preCA_12 if tt_preCA_12>abs(xpreCA_12);scalar npreCA12=r(N);
sum tt_preCA_34 if tt_preCA_34>abs(xpreCA_34);scalar npreCA34=r(N);

sum tt_rfWA_0 if tt_rfWA_0>abs(xrfWA_0);scalar nWA0=r(N);
sum tt_preWA_12 if tt_preWA_12>abs(xpreWA_12);scalar npreWA12=r(N);
sum tt_preWA_34 if tt_preWA_34>abs(xpreWA_34);scalar npreCA34=r(N);


sum F_lrsum if F_lrsum>abs(xF_lrsum);scalar nF_lrsum=r(N);
sum F_wtlrsum if F_wtlrsum>(xF_wtlrsum);scalar nF_wtlrsum=r(N);
sum F_diffCT if F_diffCT>xF_diffCT;scalar nF_diffCT=r(N);
sum F_diffIN if F_diffIN>xF_diffIN;scalar nF_diffIN=r(N);

scalar list;
log close;
