#delimit;
cd "C:\Users\cemood\Box Sync\redflag";
use "C:\Users\cemood\Box Sync\redflag\US suicide dataset_20181217.dta", clear;
*log using redflag.suicide.dummy.spline.log, replace;
scalar drop _all;

tsset state year;

/********************* total suicide rate ***********************************************/

gen lspc=lntotalsuicide;
label var lspc "Log suicide rate" ;
gen lspc_1=L.lspc;
gen lspc_2=LL.lspc;
label var lspc_1 "Log suicide rate lagged once";
label var lspc_2 "Log suicide rate lagged twice";


/***************************************************/
/* CT implemented red flag law 10/1/1999           */
/* IN implemented red flag law 7/1/2005            */
/* CA implemented red flag law 1/1/2016            */
/* OR 1/1/2018  too recent to analyze              */
/* WA 12/8/2016                                    */
/***************************************************/

/* create dummy and spline */
gen dumCT=(year>1999)*(stnm=="CT");replace dumCT=.25 if year==1999 & stnm=="CT";
gen dumIN=(year>2005)*(stnm=="IN");replace dumIN=.25 if year==2005 & stnm=="IN";
gen dumCA=(year>=2016)*(stnm=="CA");
gen dumWA=(year>2016)*(stnm=="WA");replace dumWA=.06 if year==2016 & stnm=="WA";
gen rfdum=0;
replace rfdum=dumCT+dumIN+dumCA+dumWA;
label var rfdum "Red flag dummy variable";

gen sCT=(year-1999)*(stnm=="CT")*(year>1999);
gen sIN=(year-2005)*(stnm=="IN")*(year>2005);
gen sCA=(year-2016)*(stnm=="CA")*(year>=2016);
gen sWA=(year-2016)*(stnm=="WA")*(year>2016);

gen rfspline=sCT+sIN+sCA+sWA;
label var rfspline "Red flag spline variable";

drop pp1534;

/* state and year dummies */
quietly: tab year, gen(yrdum);
quietly: tab state, gen(stdum);


replace employ=employ/poptot;
replace empconpc=100*empcon/poptot;
replace empmilpc=100*empmil/poptot;

/* use updated prison rate, income, density */
replace prisonpc=PrisonRate;
replace incomepc=IncomeperCapita;
replace density=poptot/area;
gen prisonpc_1=L.prisonpc;
gen policepc_1=L.policepc;
gen arrestvio=Violentcrimearrestrate;

label var arrestvio "Arrest rate violent crime";
label var prisonpc_1 "Prison per cap, lagged";
label var policepc_1 "Police per cap, lagged";
label var rwelfare "Real welfare per capita";
label var pp1519 "Percent Population 15-19";
label var pp2024 "Percent Population 20-24";
label var pp2529 "Percent Population 25-29";
label var pp3034 "Percent Population 30-34";
label var pp3539 "Percent Population 35-39";
label var pp4044 "Percent Population 40-44";
label var pp4549 "Percent Population 45-49";
label var pp5054 "Percent Population 50-54";
label var pp5559 "Percent Population 55-59"; 
label var pp6064 "Percent Population 60-64";
label var pp6500 "Percent Population 65+";

/* dummy and spline regression */

regress lspc 
rfdum rfspline
trend 
crack 
castle 
fse wait bkghg 
snsban 
unrate 
pp*
lspc_1 lspc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_suicide, varlabels  nosubstat starlevels(5 1) replace ctitles(Variable,Coeff,T-ratio) 
keep(
rfdum rfspline
trend 
crack 
castle 
fse wait bkghg 
snsban 
unrate 
pp*
lspc_1 lspc_2
) summstat(N);

/* dummy regression */

regress lspc 
rfdum 
trend 
crack 
castle 
fse wait bkghg 
snsban 
unrate 
pp*
lspc_1 lspc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_suicide, varlabels  nosubstat starlevels(5 1) replace ctitles(**,Coeff,T-ratio) merge
keep(
rfdum 
trend 
crack 
castle 
fse wait bkghg 
snsban 
unrate 
pp*
lspc_1 lspc_2
) summstat(N);

/* spline regression */

regress lspc 
rfspline 
trend 
crack 
castle 
fse wait bkghg 
snsban 
unrate 
pp*
lspc_1 lspc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_suicide, varlabels  nosubstat starlevels(5 1) replace ctitles(**,Coeff,T-ratio) merge
keep(
rfspline 
trend 
crack 
castle 
fse wait bkghg 
snsban 
unrate 
pp*
lspc_1 lspc_2
) summstat(N);

log close;
