#delimit;
cd "C:\Users\cemood\Box Sync\redflag";
use "C:\Users\cemood\Box Sync\redflag\US suicide dataset_20181220_updated.dta", clear;
log using redflag.assault.spline.gets.log, replace;
scalar drop _all;

tsset state year;

/***************************************************/
/* CT implemented red flag law 10/1/1999           */
/* IN implemented red flag law 7/1/2005            */
/* CA implemented red flag law 1/1/2016            */
/* OR 1/1/2018  too recent to analyze              */
/* WA 12/8/2016                                    */
/***************************************************/

gen lcrasspc=100*log(crasspc);
label var lcrasspc "Log assault rate";


/* create dummy and spline */
gen dumCT=(year>1999)*(stnm=="CT");replace dumCT=.25 if year==1999 & stnm=="CT";
gen dumIN=(year>2005)*(stnm=="IN");replace dumIN=.25 if year==2005 & stnm=="IN";
gen dumCA=(year>=2016)*(stnm=="CA");
gen dumWA=(year>2016)*(stnm=="WA");replace dumWA=.06 if year==2016 & stnm=="WA";
gen rfdum=0;
replace rfdum=dumCT+dumIN+dumCA+dumWA;
label var rfdum "Red flag dummy variable";

gen sCT=(year-1999)*(stnm=="CT")*(year>1999);
gen sIN=(year-2005)*(stnm=="IN")*(year>2005);
gen sCA=(year-2016)*(stnm=="CA")*(year>=2016);
gen sWA=(year-2016)*(stnm=="WA")*(year>2016);

gen rfspline=sCT+sIN+sCA+sWA;
label var rfspline "Red flag spline variable";

drop pp1534;

/* state and year dummies */
quietly: tab year, gen(yrdum);
quietly: tab state, gen(stdum);


replace employ=employ/poptot;
replace empconpc=100*empcon/poptot;
replace empmilpc=100*empmil/poptot;

/* use updated prison rate, income, density */
replace prisonpc=PrisonRate;
replace incomepc=IncomeperCapita;
replace density=poptot/area;
gen prisonpc_1=L.prisonpc;
gen policepc_1=L.policepc;
gen lcrasspc_1=L.lcrasspc;
gen lcrasspc_2=LL.lcrasspc;
gen arrestvio=Violentcrimearrestrate;

label var arrestvio "Arrest rate violent crime";
label var prisonpc_1 "Prison per cap, lagged";
label var policepc_1 "Police per cap, lagged";
label var lcrasspc_1 "Log assaulgt rate, lagged";
label var lcrasspc_2 "Log assault rate, lagged twice";
label var rwelfare "Real welfare per capita";
label var pp1519 "Percent Population 15-19";
label var pp2024 "Percent Population 20-24";
label var pp2529 "Percent Population 25-29";
label var pp3034 "Percent Population 30-34";
label var pp3539 "Percent Population 35-39";
label var pp4044 "Percent Population 40-44";
label var pp4549 "Percent Population 45-49";
label var pp5054 "Percent Population 50-54";
label var pp5559 "Percent Population 55-59"; 
label var pp6064 "Percent Population 60-64";
label var pp6500 "Percent Population 65+";


/* dummy and spline regression */

regress lcrasspc 
rfspline
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrasspc_1 lcrasspc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);
predict e, resid;

/* save for placebo law program */
/* keep t-ratios for placebo law program */
scalar xrfspline=_b[rfspline]/_se[rfspline];



* test demographic variables as a group */
testparm pp*;

/* test year dummies as a group */
testparm yrdum*;

/* test state trends as a group */
testparm tr2-tr51;


/* test for serial correlation  */
/* for information only, clustering cures autocorr */


regress e L.e
rfspline
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrasspc_1 lcrasspc_2
yrdum* tr2-tr51 stdum*, vce(cluster state);


tempfile temp1;
save "`temp1'";

*****************************************/
/***** placebo law program          *****/
/* generate critical values for t-test  */
/****************************************/

drop rf*;

program drop _all;
set seed 123456789;

program placebo, rclass;

* randomly choose without replacement 6 of 51 states, but skip DC=9 (not in sample) ;

mata: x=jumble(range(1,51,1));
mata: st_matrix("x",x);

/* p1 */
scalar p1=x[1,1];
forvalues i=1(1)51 {;
display p1;
if p1==7 | p1==15 | p1==5 | p1==48 {;
scalar p1=x[1+`i',1];
display as text "new p1=" p1;
continue;
};
else {;
continue,break;
};
};


/* p2 */
scalar p2=x[2,1];
forvalues i=1(1)51 {;
if p2==7 | p2==15 | p2==5 | p2==48 | p2==p1 {;
scalar p2=x[1+`i',1];
display p2;
continue;
};
else {;
continue,break;
};
};

/* p3 */
scalar p3=x[3,1];
forvalues i=1(1)51 {;
if p3==7 | p3==15 | p3==5 | p3==48 | p3==p1 | p3==p2 {;
scalar p3=x[1+`i',1];
display p3;
continue;
};
else {;
continue,break;
};
};

/* p4 */
scalar p4=x[4,1];
forvalues i=1(1)51 {;
if p4==7 | p4==15 | p4==5 | p4==48 | p4==p1 | p4==p2 | p4==p3{;
scalar p4=x[1+`i',1];
display p4;
continue;
};
else {;
continue,break;
};
};

/* create dummy and spline */
drop dum* rfdum* sCT sIN sCA sWA rf*;

gen dumCT=(year>1999)*(state==p1);replace dumCT=.25 if year==1999 & state==p1;
gen dumIN=(year>2005)*(state==p2);replace dumIN=.25 if year==2005 & state==p2;
gen dumCA=(year>=2016)*(state==p3);
gen dumWA=(year>2016)*(state==p4);replace dumWA=.06 if year==2016 & state==p4;
gen rfdum=0;
replace rfdum=dumCT+dumIN+dumCA+dumWA;
label var rfdum "Red flag dummy variable";

gen sCT=(year-1999)*(state==p1)*(year>1999);
gen sIN=(year-2005)*(state==p2)*(year>2005);
gen sCA=(year-2016)*(state==p3)*(year>=2016);
gen sWA=(year-2016)*(state==p4)*(year>2016);

gen rfspline=sCT+sIN+sCA+sWA;
label var rfspline "Red flag spline variable";

regress lcrasspc 
rfspline
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrasspc_1 lcrasspc_2 
yrdum*  stdum* 
tr2-tr51
[weight=poptot]
, robust cluster(state);


end;


simulate placebo _b _se , reps(1000);

/* get scalars from temp1 */
tempfile temp2;
save "`temp2'";

use `temp1';
drop _all;
set obs 1000;
gen index=_n;
sum;
scalar list;
save `temp1', replace;
use `temp2';
gen index=_n;
merge 1:1 index using `temp1';

/* placebo t-ratios */
gen t_rfspline=b_rfspline/se_rfspline;gen tt_rfspline=abs(t_rfspline);
sum tt_rfspline, detail;

/* p-values for t-statistics */

sum tt_rfspline if tt_rfspline>abs(xrfspline);scalar nrfspline=r(N);

scalar list;
log close;
