#delimit;
cd "C:\Users\cemood\Box Sync\redflag";
use "C:\Users\cemood\Box Sync\redflag\US suicide dataset_20181220_updated.dta", clear;
*log using table_4.log, replace;
scalar drop _all;

tsset state year;

/***************************************************/
/* CT implemented red flag law 10/1/1999           */
/* IN implemented red flag law 7/1/2005            */
/* CA implemented red flag law 1/1/2016            */
/* OR 1/1/2018  too recent to analyze              */
/* WA 12/8/2016                                    */
/***************************************************/

/* create dummy and spline */
gen dumCT=(year>1999)*(stnm=="CT");replace dumCT=.25 if year==1999 & stnm=="CT";
gen dumIN=(year>2005)*(stnm=="IN");replace dumIN=.25 if year==2005 & stnm=="IN";
gen dumCA=(year>=2016)*(stnm=="CA");
gen dumWA=(year>2016)*(stnm=="WA");replace dumWA=.06 if year==2016 & stnm=="WA";
gen rfdum=0;
replace rfdum=dumCT+dumIN+dumCA+dumWA;
label var rfdum "Red flag dummy variable";

gen sCT=(year-1999)*(stnm=="CT")*(year>1999);
gen sIN=(year-2005)*(stnm=="IN")*(year>2005);
gen sCA=(year-2016)*(stnm=="CA")*(year>=2016);
gen sWA=(year-2016)*(stnm=="WA")*(year>2016);

gen rfspline=sCT+sIN+sCA+sWA;
label var rfspline "Red flag spline variable";

drop pp1534;

/* state and year dummies */
quietly: tab year, gen(yrdum);
quietly: tab state, gen(stdum);


replace employ=employ/poptot;
replace empconpc=100*empcon/poptot;
replace empmilpc=100*empmil/poptot;

/* use updated prison rate, income, density */
replace prisonpc=PrisonRate;
replace incomepc=IncomeperCapita;
replace density=poptot/area;
gen prisonpc_1=L.prisonpc;
gen policepc_1=L.policepc;
gen lcrmurpc_1=L.lcrmurpc;
gen lcrmurpc_2=LL.lcrmurpc;
gen arrestvio=Violentcrimearrestrate;

label var arrestvio "Arrest rate violent crime";
label var prisonpc_1 "Prison per cap, lagged";
label var policepc_1 "Police per cap, lagged";
label var lcrmurpc_1 "Log gun murder rate, lagged";
label var lcrmurpc_2 "Log gun murder rate, lagged twice";
label var rwelfare "Real welfare per capita";
label var pp1519 "Percent Population 15-19";
label var pp2024 "Percent Population 20-24";
label var pp2529 "Percent Population 25-29";
label var pp3034 "Percent Population 30-34";
label var pp3539 "Percent Population 35-39";
label var pp4044 "Percent Population 40-44";
label var pp4549 "Percent Population 45-49";
label var pp5054 "Percent Population 50-54";
label var pp5559 "Percent Population 55-59"; 
label var pp6064 "Percent Population 60-64";
label var pp6500 "Percent Population 65+";


/************************************************************************ dummy and spline regressions ***********************************************************/

gen lcrrappc=100*log(crrappc);
gen lcrrappc_1=L.lcrrappc;
gen lcrrappc_2=LL.lcrrappc;

regress lcrrappc 
rfdum rfspline
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrrappc_1 lcrrappc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Rape) 
keep(
rfdum rfspline
) ;


gen lcrrobpc=100*log(crrobpc);
gen lcrrobpc_1=L.lcrrobpc;
gen lcrrobpc_2=LL.lcrrobpc;

regress lcrrobpc 
rfdum rfspline
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrrobpc_1 lcrrobpc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Robbery) merge
keep(
rfdum rfspline
) ;

gen lcrasspc=100*log(crasspc);
gen lcrasspc_1=L.lcrasspc;
gen lcrasspc_2=LL.lcrasspc;

regress lcrasspc 
rfdum rfspline
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrasspc_1 lcrasspc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);


outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Assault) merge
keep(
rfdum rfspline
) ;


gen lcrburpc=100*log(crburpc);
gen lcrburpc_1=L.lcrburpc;
gen lcrburpc_2=LL.lcrburpc;

regress lcrburpc 
rfdum rfspline
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrburpc_1 lcrburpc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);


outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Burglary) merge
keep(
rfdum rfspline
) ;

/**************************************************************** dummy only regressions *****************************************************************/

regress lcrrappc 
rfdum 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrrappc_1 lcrrappc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Rape) merge

keep(
rfdum 
) ;

regress lcrrobpc 
rfdum 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrrobpc_1 lcrrobpc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Robbery) merge

keep(
rfdum
) ;

regress lcrasspc 
rfdum 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrasspc_1 lcrasspc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Assault) merge

keep(
rfdum
) ;

regress lcrburpc 
rfdum 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500

lcrburpc_1 lcrburpc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Burglary) merge

keep(
rfdum 
) ;


/*************************************************************************************** spline only regressions *********************************************************/

regress lcrrappc 
rfspline 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrrappc_1 lcrrappc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Rape) merge

keep(
rfspline 
) ;

regress lcrrobpc 
rfspline 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrrobpc_1 lcrrobpc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Robbery) merge

keep(
rfspline 
) ;

regress lcrasspc 
rfspline 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrasspc_1 lcrasspc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Assault) merge

keep(
rfspline 
) ;

regress lcrburpc 
rfspline 
trend 
crack 
arrestvio
prisonpc_1 
strike3
wait bkgp 
snsban 
incomepc povrate pctblack
unrate employ  empconpc
pp6500
lcrburpc_1 lcrburpc_2
yrdum* tr* stdum* 
[weight=poptot]
, robust cluster(state);

outreg using table_4, varlabels   starlevels(5 1) replace ctitles(Variable,Burglary) merge

keep(
rfspline 
) ;

log close;
